@@ -1,5 +1,5 @@
 pbtpn <-
-function(x, sigma, lambda, eta, lower.tail = TRUE, log = FALSE)
+function(x, sigma=1, lambda=0, eta=0, lower.tail = TRUE, log = FALSE)
 {
     if (is.null(x)) 
         stop("x must be specified")
